using System;
using System.Collections.Generic;
using System.IO;
using UnityEngine;
using UnityEngine.Events;

namespace Mod
{
    public class Mod
    {
        public static void Main()
        {
ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Pistol"),
        NameOverride = "Eder 22 [BWP: Ranged Weapons]",
        DescriptionOverride = "Low Impact, Low damage",
        CategoryOverride = ModAPI.FindCategory("Firearms"),
        ThumbnailOverride = ModAPI.LoadSprite("eder22/thumb.png"),
        AfterSpawn = (Instance) =>
        {
            //This line of code sets the sprite after the gun is spawned in.
            Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("eder22/eder22.png");
            
            //Since we'll be referencing this a few times in the code, it's better to cache it here to save like, a couple of nanoseconds. I guess.
            var firearm = Instance.GetComponent<FirearmBehaviour>();

            //The way most guns work in People Playground is by taking a ScriptableObject called "Cartridge", and loading it into the FirearmBehaviour. Some things here are self-explanatory.
            Cartridge customCartridge = ModAPI.FindCartridge("9 mm");
            customCartridge.name = "Eder22 Catridge";
            customCartridge.Damage *= 3f;
            //notice that this is using *= instead of =, that's because it's modifying the original cartridge's values instead of setting them from scratch.
            customCartridge.StartSpeed *= 0.5f; //Bullet velocity
            customCartridge.Recoil *= 2f;
            customCartridge.PenetrationRandomAngleMultiplier *= 0.25f; //Changes the accuracy of a bullet after colliding with an object.
            customCartridge.ImpactForce *= 10f; //The force applied once the bullet makes collides

            //remember that variable we bullied earlier? this is him now. a gun. i bet you feel stupid
            firearm.Cartridge = customCartridge;

            //This array is randomly picked from when the gun is fired.
            firearm.ShotSounds = new AudioClip[]
            {
                ModAPI.LoadSound("eder22/eder22-1.wav"),
                ModAPI.LoadSound("eder22/eder22-2.wav"),
                ModAPI.LoadSound("eder22/eder22-3.wav"),
            };

            Instance.FixColliders();
        }
    }
);



ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Pistol"),
        NameOverride = "1911 [BWP: Ranged Weapons]",
        DescriptionOverride = "High Impact, High damage",
        CategoryOverride = ModAPI.FindCategory("Firearms"),
        ThumbnailOverride = ModAPI.LoadSprite("1911/thumb.png"),
        AfterSpawn = (Instance) =>
        {
            //This line of code sets the sprite after the gun is spawned in.
            Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("1911/1911.png");
            //Since we'll be referencing this a few times in the code, it's better to cache it here to save like, a couple of nanoseconds. I guess.
            var firearm = Instance.GetComponent<FirearmBehaviour>();

            //The way most guns work in People Playground is by taking a ScriptableObject called "Cartridge", and loading it into the FirearmBehaviour. Some things here are self-explanatory.
            Cartridge customCartridge = ModAPI.FindCartridge("9 mm");
            customCartridge.name = "1911 Catridge";
            customCartridge.Damage *= 7f;
            customCartridge.StartSpeed *= 0.5f; //Bullet velocity
            customCartridge.Recoil *= 2f;
            customCartridge.PenetrationRandomAngleMultiplier *= 0.25f; //Changes the accuracy of a bullet after colliding with an object.
            customCartridge.ImpactForce *= 1f; //The force applied once the bullet makes collides

            //remember that variable we bullied earlier? this is him now. a gun. i bet you feel stupid
            firearm.Cartridge = customCartridge;

            //This array is randomly picked from when the gun is fired.
            firearm.ShotSounds = new AudioClip[]
            {
                ModAPI.LoadSound("1911/1911-1.wav"),
                ModAPI.LoadSound("1911/1911-2.wav"),
                ModAPI.LoadSound("1911/1911-3.wav"),
            };

            Instance.FixColliders();
        }
    }
);



ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Submachine Gun"),
        NameOverride = "Gold MP5K [BWP: Ranged Weapons]",
        DescriptionOverride = "A little overpowered",
        CategoryOverride = ModAPI.FindCategory("Firearms"),
        ThumbnailOverride = ModAPI.LoadSprite("mp5k/gold/thumb.png"),
        AfterSpawn = (Instance) =>
        {
            //This line of code sets the sprite after the gun is spawned in.
            Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("mp5k/gold/mp5k.png");
            //Since we'll be referencing this a few times in the code, it's better to cache it here to save like, a couple of nanoseconds. I guess.
            var firearm = Instance.GetComponent<FirearmBehaviour>();

            //The way most guns work in People Playground is by taking a ScriptableObject called "Cartridge", and loading it into the FirearmBehaviour. Some things here are self-explanatory.
            Cartridge customCartridge = ModAPI.FindCartridge("120 mm");
            //In order to get a baseline of the Cartridge, it's easier to load in a pre-existing one. A list of the game's cartridges will be found underneath this.
            customCartridge.name = "Overpowered Cartridge";
            //set a new name for the new cartridge
            customCartridge.Damage *= 3f;
            //notice that this is using *= instead of =, that's because it's modifying the original cartridge's values instead of setting them from scratch.
            customCartridge.StartSpeed *= 1f; //Bullet velocity
            customCartridge.Recoil *= 2f;
                        customCartridge.PenetrationRandomAngleMultiplier *= 0.25f; //Changes the accuracy of a bullet after colliding with an object.
            customCartridge.ImpactForce *= 2f; //The force applied once the bullet makes collides

            //remember that variable we bullied earlier? this is him now. a gun. i bet you feel stupid
            firearm.Cartridge = customCartridge;

            //This array is randomly picked from when the gun is fired.
            firearm.ShotSounds = new AudioClip[]
            {
                ModAPI.LoadSound("mp5k/mp5k-1.wav"),
                ModAPI.LoadSound("mp5k/mp5k-2.wav"),
                ModAPI.LoadSound("mp5k/mp5k-3.wav"),
            };

            Instance.FixColliders();
        }
    }
);



ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Submachine Gun"),
        NameOverride = "MP5k [BWP: Ranged Weapons]",
        DescriptionOverride = "Little baby MP5k",
        CategoryOverride = ModAPI.FindCategory("Firearms"),
        ThumbnailOverride = ModAPI.LoadSprite("mp5k/black/thumb.png"),
        AfterSpawn = (Instance) =>
        {
            //This line of code sets the sprite after the gun is spawned in.
            Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("mp5k/black/mp5k.png");
            //Since we'll be referencing this a few times in the code, it's better to cache it here to save like, a couple of nanoseconds. I guess.
            var firearm = Instance.GetComponent<FirearmBehaviour>();

            //The way most guns work in People Playground is by taking a ScriptableObject called "Cartridge", and loading it into the FirearmBehaviour. Some things here are self-explanatory.
            Cartridge customCartridge = ModAPI.FindCartridge("9mm");
            //In order to get a baseline of the Cartridge, it's easier to load in a pre-existing one. A list of the game's cartridges will be found underneath this.
            customCartridge.name = "MP5k Cartridge";
            //set a new name for the new cartridge
            customCartridge.Damage *= 3f;
            //notice that this is using *= instead of =, that's because it's modifying the original cartridge's values instead of setting them from scratch.
            customCartridge.StartSpeed *= 0.75f; //Bullet velocity
            customCartridge.Recoil *= 2f;
                       customCartridge.PenetrationRandomAngleMultiplier *= 0.25f; //Changes the accuracy of a bullet after colliding with an object.
            customCartridge.ImpactForce *= 2f; //The force applied once the bullet makes collides

            //remember that variable we bullied earlier? this is him now. a gun. i bet you feel stupid
            firearm.Cartridge = customCartridge;

            //This array is randomly picked from when the gun is fired.
            firearm.ShotSounds = new AudioClip[]
            {
                ModAPI.LoadSound("mp5k/mp5k-1.wav"),
                ModAPI.LoadSound("mp5k/mp5k-2.wav"),
                ModAPI.LoadSound("mp5k/mp5k-3.wav"),
            };

            Instance.FixColliders();
        }
    }
);




ModAPI.Register(
    new Modification()
        {
        OriginalItem = ModAPI.FindSpawnable("Submachine Gun"),
        NameOverride = "MP5k - Sabrelake [BWP: Ranged Weapons]",
        DescriptionOverride = "Banana boy",
        CategoryOverride = ModAPI.FindCategory("Firearms"),
        ThumbnailOverride = ModAPI.LoadSprite("mp5k/sabrelake/thumb.png"),
        AfterSpawn = (Instance) =>
        {
            //This line of code sets the sprite after the gun is spawned in.
            Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("mp5k/sabrelake/mp5k.png");
            //Since we'll be referencing this a few times in the code, it's better to cache it here to save like, a couple of nanoseconds. I guess.
            var firearm = Instance.GetComponent<FirearmBehaviour>();

            //The way most guns work in People Playground is by taking a ScriptableObject called "Cartridge", and loading it into the FirearmBehaviour. Some things here are self-explanatory.
            Cartridge customCartridge = ModAPI.FindCartridge("9mm");
            //In order to get a baseline of the Cartridge, it's easier to load in a pre-existing one. A list of the game's cartridges will be found underneath this.
            customCartridge.name = "MP5k Cartridge";
            //set a new name for the new cartridge
            customCartridge.Damage *= 3f;
            //notice that this is using *= instead of =, that's because it's modifying the original cartridge's values instead of setting them from scratch.
            customCartridge.StartSpeed *= 0.75f; //Bullet velocity
            customCartridge.Recoil *= 2f;
                        customCartridge.PenetrationRandomAngleMultiplier *= 0.25f; //Changes the accuracy of a bullet after colliding with an object.
            customCartridge.ImpactForce *= 2f; //The force applied once the bullet makes collides

            //remember that variable we bullied earlier? this is him now. a gun. i bet you feel stupid
            firearm.Cartridge = customCartridge;

            //This array is randomly picked from when the gun is fired.
            firearm.ShotSounds = new AudioClip[]
            {
                ModAPI.LoadSound("mp5k/mp5k-1.wav"),
                ModAPI.LoadSound("mp5k/mp5k-2.wav"),
                ModAPI.LoadSound("mp5k/mp5k-3.wav"),
            };

            Instance.FixColliders();
        }
    }
);



ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Submachine Gun"),
        NameOverride = "MP5k - Melonbelly [BWP: Ranged Weapons]",
        DescriptionOverride = "Perfect for keeping intruders out of your illegal melon farm.",
        CategoryOverride = ModAPI.FindCategory("Firearms"),
        ThumbnailOverride = ModAPI.LoadSprite("mp5k/melonbelly/thumb.png"),
            AfterSpawn = (Instance) =>
            {
            //This line of code sets the sprite after the gun is spawned in.
            Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("mp5k/melonbelly/mp5k.png");
            //Since we'll be referencing this a few times in the code, it's better to cache it here to save like, a couple of nanoseconds. I guess.
            var firearm = Instance.GetComponent<FirearmBehaviour>();

            //The way most guns work in People Playground is by taking a ScriptableObject called "Cartridge", and loading it into the FirearmBehaviour. Some things here are self-explanatory.
            Cartridge customCartridge = ModAPI.FindCartridge("9mm");
            //In order to get a baseline of the Cartridge, it's easier to load in a pre-existing one. A list of the game's cartridges will be found underneath this.
            customCartridge.name = "MP5k Cartridge";
            //set a new name for the new cartridge
            customCartridge.Damage *= 3f;
            //notice that this is using *= instead of =, that's because it's modifying the original cartridge's values instead of setting them from scratch.
            customCartridge.StartSpeed *= 0.5f; //Bullet velocity
            customCartridge.Recoil *= 2f;
                        customCartridge.PenetrationRandomAngleMultiplier *= 0.25f; //Changes the accuracy of a bullet after colliding with an object.
            customCartridge.ImpactForce *= 2f; //The force applied once the bullet makes collides

            //remember that variable we bullied earlier? this is him now. a gun. i bet you feel stupid
            firearm.Cartridge = customCartridge;

            //This array is randomly picked from when the gun is fired.
            firearm.ShotSounds = new AudioClip[]
            {
                ModAPI.LoadSound("mp5k/mp5k-1.wav"),
                ModAPI.LoadSound("mp5k/mp5k-2.wav"),
                ModAPI.LoadSound("mp5k/mp5k-3.wav"),
            };

            Instance.FixColliders();
        }
    }
);



ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Assault Rifle"),
        NameOverride = "M16 [BWP: Ranged Weapons]",
        DescriptionOverride = "Where's my carry handle?",
        CategoryOverride = ModAPI.FindCategory("Firearms"),
        ThumbnailOverride = ModAPI.LoadSprite("m16/m16/thumb.png"),
            AfterSpawn = (Instance) =>
            {
            //This line of code sets the sprite after the gun is spawned in.
            Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("m16/m16/m16.png");
            //Since we'll be referencing this a few times in the code, it's better to cache it here to save like, a couple of nanoseconds. I guess.
            var firearm = Instance.GetComponent<FirearmBehaviour>();

            //The way most guns work in People Playground is by taking a ScriptableObject called "Cartridge", and loading it into the FirearmBehaviour. Some things here are self-explanatory.
            Cartridge customCartridge = ModAPI.FindCartridge("5.56x45mm");
            //In order to get a baseline of the Cartridge, it's easier to load in a pre-existing one. A list of the game's cartridges will be found underneath this.
            customCartridge.name = "M16 cartridge";
            //set a new name for the new cartridge
            customCartridge.Damage *= 3f;
            //notice that this is using *= instead of =, that's because it's modifying the original cartridge's values instead of setting them from scratch.
            customCartridge.StartSpeed *= 0.5f; //Bullet velocity
            customCartridge.Recoil *= 2f;
                        customCartridge.PenetrationRandomAngleMultiplier *= 0.25f; //Changes the accuracy of a bullet after colliding with an object.
            customCartridge.ImpactForce *= 2f; //The force applied once the bullet makes collides

            //remember that variable we bullied earlier? this is him now. a gun. i bet you feel stupid
            firearm.Cartridge = customCartridge;

            //This array is randomly picked from when the gun is fired.
            firearm.ShotSounds = new AudioClip[]
            {
                ModAPI.LoadSound("pow.wav"),
                ModAPI.LoadSound("bang.wav"),
                ModAPI.LoadSound("pop.wav"),
            };

            Instance.FixColliders();
        }
    }
);



ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Rifle"),
        NameOverride = "M16 / Acog [BWP: Ranged Weapons]",
        DescriptionOverride = "Where's my carry handle?",
        CategoryOverride = ModAPI.FindCategory("Firearms"),
        ThumbnailOverride = ModAPI.LoadSprite("m16/m16a/thumb.png"),
        AfterSpawn = (Instance) =>
        {
            //This line of code sets the sprite after the gun is spawned in.
            Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("m16/m16a/m16a.png");
            //Since we'll be referencing this a few times in the code, it's better to cache it here to save like, a couple of nanoseconds. I guess.
            var firearm = Instance.GetComponent<FirearmBehaviour>();

            Cartridge customCartridge = ModAPI.FindCartridge("9mm");
            customCartridge.name = "M16 cartridge";
            customCartridge.Damage *= 3f;
            customCartridge.StartSpeed *= 0.5f; //Bullet velocity
            customCartridge.Recoil *= 2f;
            customCartridge.PenetrationRandomAngleMultiplier *= 0.25f; //Changes the accuracy of a bullet after colliding with an object.
            customCartridge.ImpactForce *= 2f; //The force applied once the bullet makes collides

            //remember that variable we bullied earlier? this is him now. a gun. i bet you feel stupid
            firearm.Cartridge = customCartridge;

            //This array is randomly picked from when the gun is fired.
            firearm.ShotSounds = new AudioClip[]
            {
                ModAPI.LoadSound("pow.wav"),
                ModAPI.LoadSound("bang.wav"),
                ModAPI.LoadSound("pop.wav"),
            };

            Instance.FixColliders();
        }
    }
);



ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Assault Rifle"),
        NameOverride = "M16 / Grip / Laser [BWP: Ranged Weapons]",
        DescriptionOverride = "As compensation for the lack of a carrying handle I added some attachments",
        CategoryOverride = ModAPI.FindCategory("Firearms"),
        ThumbnailOverride = ModAPI.LoadSprite("m16/m16gl/thumb.png"),
        AfterSpawn = (Instance) =>
        {
            //This line of code sets the sprite after the gun is spawned in.
            Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("m16/m16gl/m16gl.png");
            //Since we'll be referencing this a few times in the code, it's better to cache it here to save like, a couple of nanoseconds. I guess.
            var firearm = Instance.GetComponent<FirearmBehaviour>();

            //The way most guns work in People Playground is by taking a ScriptableObject called "Cartridge", and loading it into the FirearmBehaviour. Some things here are self-explanatory.
            Cartridge customCartridge = ModAPI.FindCartridge("5.56x45mm");
            //In order to get a baseline of the Cartridge, it's easier to load in a pre-existing one. A list of the game's cartridges will be found underneath this.
            customCartridge.name = "M16 cartridge";
            //set a new name for the new cartridge
            customCartridge.Damage *= 3f;
            //notice that this is using *= instead of =, that's because it's modifying the original cartridge's values instead of setting them from scratch.
            customCartridge.StartSpeed *= 0.5f; //Bullet velocity
            customCartridge.Recoil *= 2f;
                        customCartridge.PenetrationRandomAngleMultiplier *= 0.25f; //Changes the accuracy of a bullet after colliding with an object.
            customCartridge.ImpactForce *= 2f; //The force applied once the bullet makes collides

            //remember that variable we bullied earlier? this is him now. a gun. i bet you feel stupid
            firearm.Cartridge = customCartridge;

            //This array is randomly picked from when the gun is fired.
            firearm.ShotSounds = new AudioClip[]
            {
                ModAPI.LoadSound("pow.wav"),
                ModAPI.LoadSound("bang.wav"),
                ModAPI.LoadSound("pop.wav"),
            };

            Instance.FixColliders();
        }
    }
);



ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Assault Rifle"),
        NameOverride = "MK18 [BWP: Ranged Weapons]",
        DescriptionOverride = "Its a gun",
        CategoryOverride = ModAPI.FindCategory("Firearms"),
        ThumbnailOverride = ModAPI.LoadSprite("mk18/tan/thumb.png"),
            AfterSpawn = (Instance) =>
            {
            //This line of code sets the sprite after the gun is spawned in.
            Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("mk18/tan/mk18.png");
            //Since we'll be referencing this a few times in the code, it's better to cache it here to save like, a couple of nanoseconds. I guess.
            var firearm = Instance.GetComponent<FirearmBehaviour>();

            //The way most guns work in People Playground is by taking a ScriptableObject called "Cartridge", and loading it into the FirearmBehaviour. Some things here are self-explanatory.
            Cartridge customCartridge = ModAPI.FindCartridge("5.56x45mm");
            //In order to get a baseline of the Cartridge, it's easier to load in a pre-existing one. A list of the game's cartridges will be found underneath this.
            customCartridge.name = "Mk18 cartridge";
            //set a new name for the new cartridge
            customCartridge.Damage *= 3f;
            //notice that this is using *= instead of =, that's because it's modifying the original cartridge's values instead of setting them from scratch.
            customCartridge.StartSpeed *= 0.5f; //Bullet velocity
            customCartridge.Recoil *= 2f;
                        customCartridge.PenetrationRandomAngleMultiplier *= 0.25f; //Changes the accuracy of a bullet after colliding with an object.
            customCartridge.ImpactForce *= 2f; //The force applied once the bullet makes collides

            //remember that variable we bullied earlier? this is him now. a gun. i bet you feel stupid
            firearm.Cartridge = customCartridge;

            //This array is randomly picked from when the gun is fired.
            firearm.ShotSounds = new AudioClip[]
                                    {
                ModAPI.LoadSound("pow.wav"),
                ModAPI.LoadSound("bang.wav"),
                ModAPI.LoadSound("pop.wav"),
            };

            Instance.FixColliders();
        }
    }
);



ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Assault Rifle"),
        NameOverride = "MK18 - Sabrelake [BWP: Ranged Weapons]",
        DescriptionOverride = "Bigger banana boy if the other one was to small.",
        CategoryOverride = ModAPI.FindCategory("Firearms"),
        ThumbnailOverride = ModAPI.LoadSprite("mk18/sabrelake/thumb.png"),
            AfterSpawn = (Instance) =>
            {
            //This line of code sets the sprite after the gun is spawned in.
            Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("mk18/sabrelake/mk18.png");
            //Since we'll be referencing this a few times in the code, it's better to cache it here to save like, a couple of nanoseconds. I guess.
            var firearm = Instance.GetComponent<FirearmBehaviour>();

            //The way most guns work in People Playground is by taking a ScriptableObject called "Cartridge", and loading it into the FirearmBehaviour. Some things here are self-explanatory.
            Cartridge customCartridge = ModAPI.FindCartridge("5.56x45mm");
            //In order to get a baseline of the Cartridge, it's easier to load in a pre-existing one. A list of the game's cartridges will be found underneath this.
            customCartridge.name = "Mk18 cartridge";
            //set a new name for the new cartridge
            customCartridge.Damage *= 3f;
            //notice that this is using *= instead of =, that's because it's modifying the original cartridge's values instead of setting them from scratch.
            customCartridge.StartSpeed *= 0.5f; //Bullet velocity
            customCartridge.Recoil *= 2f;
                        customCartridge.PenetrationRandomAngleMultiplier *= 0.25f; //Changes the accuracy of a bullet after colliding with an object.
            customCartridge.ImpactForce *= 2f; //The force applied once the bullet makes collides

            //remember that variable we bullied earlier? this is him now. a gun. i bet you feel stupid
            firearm.Cartridge = customCartridge;

            //This array is randomly picked from when the gun is fired.
            firearm.ShotSounds = new AudioClip[]
            {
                ModAPI.LoadSound("pow.wav"),
                ModAPI.LoadSound("bang.wav"),
                ModAPI.LoadSound("pop.wav"),
            };

            Instance.FixColliders();
        }
    }
);



ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Assault Rifle"),
        NameOverride = "MK18 - Melonbelly [BWP: Ranged Weapons]",
        DescriptionOverride = "Incase the MP5k wasn't enough to keep the intruders out.",
        CategoryOverride = ModAPI.FindCategory("Firearms"),
        ThumbnailOverride = ModAPI.LoadSprite("mk18/melonbelly/thumb.png"),
            AfterSpawn = (Instance) =>
            {
            //This line of code sets the sprite after the gun is spawned in.
            Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("mk18/melonbelly/mk18.png");
            //Since we'll be referencing this a few times in the code, it's better to cache it here to save like, a couple of nanoseconds. I guess.
            var firearm = Instance.GetComponent<FirearmBehaviour>();

            //The way most guns work in People Playground is by taking a ScriptableObject called "Cartridge", and loading it into the FirearmBehaviour. Some things here are self-explanatory.
            Cartridge customCartridge = ModAPI.FindCartridge("5.56x45mm");
            //In order to get a baseline of the Cartridge, it's easier to load in a pre-existing one. A list of the game's cartridges will be found underneath this.
            customCartridge.name = "Mk18 cartridge";
            //set a new name for the new cartridge
            customCartridge.Damage *= 3f;
            //notice that this is using *= instead of =, that's because it's modifying the original cartridge's values instead of setting them from scratch.
            customCartridge.StartSpeed *= 0.5f; //Bullet velocity
            customCartridge.Recoil *= 2f;
            customCartridge.PenetrationRandomAngleMultiplier *= 0.25f; //Changes the accuracy of a bullet after colliding with an object.
            customCartridge.ImpactForce *= 2f; //The force applied once the bullet makes collides

            //remember that variable we bullied earlier? this is him now. a gun. i bet you feel stupid
            firearm.Cartridge = customCartridge;

            //This array is randomly picked from when the gun is fired.
            firearm.ShotSounds = new AudioClip[]
            {
                ModAPI.LoadSound("pow.wav"),
                ModAPI.LoadSound("bang.wav"),
                ModAPI.LoadSound("pop.wav"),
            };
        }
    }
);



ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Assault Rifle"),
        NameOverride = "MK18 - Olive [BWP: Ranged Weapons]",
        DescriptionOverride = "Avocado gun.",
        CategoryOverride = ModAPI.FindCategory("Firearms"),
        ThumbnailOverride = ModAPI.LoadSprite("mk18/olive/thumb.png"),
            AfterSpawn = (Instance) =>
            {
            //This line of code sets the sprite after the gun is spawned in.
            Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("mk18/olive/mk18.png");
            //Since we'll be referencing this a few times in the code, it's better to cache it here to save like, a couple of nanoseconds. I guess.
            var firearm = Instance.GetComponent<FirearmBehaviour>();

            //The way most guns work in People Playground is by taking a ScriptableObject called "Cartridge", and loading it into the FirearmBehaviour. Some things here are self-explanatory.
            Cartridge customCartridge = ModAPI.FindCartridge("5.56x45mm");
            //In order to get a baseline of the Cartridge, it's easier to load in a pre-existing one. A list of the game's cartridges will be found underneath this.
            customCartridge.name = "Mk18 cartridge";
            //set a new name for the new cartridge
            customCartridge.Damage *= 3f;
            //notice that this is using *= instead of =, that's because it's modifying the original cartridge's values instead of setting them from scratch.
            customCartridge.StartSpeed *= 0.5f; //Bullet velocity
            customCartridge.Recoil *= 2f;
            customCartridge.PenetrationRandomAngleMultiplier *= 0.25f; //Changes the accuracy of a bullet after colliding with an object.
            customCartridge.ImpactForce *= 2f; //The force applied once the bullet makes collides

            //remember that variable we bullied earlier? this is him now. a gun. i bet you feel stupid
            firearm.Cartridge = customCartridge;

            //This array is randomly picked from when the gun is fired.
            firearm.ShotSounds = new AudioClip[]
            {
                ModAPI.LoadSound("pow.wav"),
                ModAPI.LoadSound("bang.wav"),
                ModAPI.LoadSound("pop.wav"),
            };

            Instance.FixColliders();
        }
    }
);



ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Assault Rifle"),
        NameOverride = "MK18 - Navy [BWP: Ranged Weapons]",
        DescriptionOverride = "For some reason the navy variant to me seems to have a higher fire rate ",
        CategoryOverride = ModAPI.FindCategory("Firearms"),
        ThumbnailOverride = ModAPI.LoadSprite("mk18/navy/thumb.png"),
            AfterSpawn = (Instance) =>
            {
            //This line of code sets the sprite after the gun is spawned in.
            Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("mk18/navy/mk18.png");
            //Since we'll be referencing this a few times in the code, it's better to cache it here to save like, a couple of nanoseconds. I guess.
            var firearm = Instance.GetComponent<FirearmBehaviour>();

            //The way most guns work in People Playground is by taking a ScriptableObject called "Cartridge", and loading it into the FirearmBehaviour. Some things here are self-explanatory.
            Cartridge customCartridge = ModAPI.FindCartridge("5.56x45mm");
            //In order to get a baseline of the Cartridge, it's easier to load in a pre-existing one. A list of the game's cartridges will be found underneath this.
            customCartridge.name = "Mk18 cartridge";
            //set a new name for the new cartridge
            customCartridge.Damage *= 3f;
            //notice that this is using *= instead of =, that's because it's modifying the original cartridge's values instead of setting them from scratch.
            customCartridge.StartSpeed *= 0.5f; //Bullet velocity
            customCartridge.Recoil *= 2f;
            customCartridge.PenetrationRandomAngleMultiplier *= 0.25f; //Changes the accuracy of a bullet after colliding with an object.
            customCartridge.ImpactForce *= 2f; //The force applied once the bullet makes collides

            //remember that variable we bullied earlier? this is him now. a gun. i bet you feel stupid
            firearm.Cartridge = customCartridge;

            //This array is randomly picked from when the gun is fired.
            firearm.ShotSounds = new AudioClip[]
            {
                ModAPI.LoadSound("pow.wav"),
                ModAPI.LoadSound("bang.wav"),
                ModAPI.LoadSound("pop.wav"),
            };

            Instance.FixColliders();
        }
    }
);



ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Pistol"),
        NameOverride = "P350 [BWP: Ranged Weapons]",
        DescriptionOverride = "Boneworks fandom says p350 is .45acp #BoneworksIsCancelled",
        CategoryOverride = ModAPI.FindCategory("Firearms"),
        ThumbnailOverride = ModAPI.LoadSprite("p350/thumb.png"),
        AfterSpawn = (Instance) =>
        {
            //This line of code sets the sprite after the gun is spawned in.
            Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("p350/p350.png");
            //Since we'll be referencing this a few times in the code, it's better to cache it here to save like, a couple of nanoseconds. I guess.
            var firearm = Instance.GetComponent<FirearmBehaviour>();

            //The way most guns work in People Playground is by taking a ScriptableObject called "Cartridge", and loading it into the FirearmBehaviour. Some things here are self-explanatory.
            Cartridge customCartridge = ModAPI.FindCartridge("9mm");
            //In order to get a baseline of the Cartridge, it's easier to load in a pre-existing one. A list of the game's cartridges will be found underneath this.
            customCartridge.name = "P350 cartridge";
            //set a new name for the new cartridge
            customCartridge.Damage *= 3f;
            //notice that this is using *= instead of =, that's because it's modifying the original cartridge's values instead of setting them from scratch.
            customCartridge.StartSpeed *= 0.5f; //Bullet velocity
            customCartridge.Recoil *= 2f;
            customCartridge.PenetrationRandomAngleMultiplier *= 0.25f; //Changes the accuracy of a bullet after colliding with an object.
            customCartridge.ImpactForce *= 2f; //The force applied once the bullet makes collides

            //remember that variable we bullied earlier? this is him now. a gun. i bet you feel stupid
            firearm.Cartridge = customCartridge;

            //This array is randomly picked from when the gun is fired.
            firearm.ShotSounds = new AudioClip[]
            {
                ModAPI.LoadSound("pow.wav"),
                ModAPI.LoadSound("bang.wav"),
                ModAPI.LoadSound("pop.wav"),
            };

            Instance.FixColliders();
        }
    }
);
        }
    }
}